[![pipeline status](https://gitlab.com/l3p-cv/lost_ds/badges/master/pipeline.svg)](https://gitlab.com/l3p-cv/lost_ds/pipelines)
<!-- [![Documentation Status](https://readthedocs.org/projects/lost_ds/badge/?version=latest)](https://lost_ds.readthedocs.io/en/latest/?badge=latest) -->

### LOSTDataset

This is a library to handle datasets generated by LOST. LOSTDataset enables 
directily producing semantic segmentations, anno-type transformations (i.e. polygon to bbox), 
anno-style transformations (i.e. bbox xywh -> bbox x1x2y1y2), crop datasets, 
visualize annotations, lost2coco and some more.

Checkout some explanation and examples [here](https://github.com/l3p-cv/lost_ds/blob/master/examples/example.ipynb).

